@@ -5,8 +5,9 @@ context("Reading from workbook is identical to reading from file readTest.xlsx")
 
 
 
-test_that("Reading example workbook", {
+test_that("Reading example workbook readTest.xlsx", {
   
+  curr_wd <- getwd()
   xlsxFile <- system.file("readTest.xlsx", package = "openxlsx")
   wb <- loadWorkbook(xlsxFile)
   
@@ -14,31 +15,45 @@ test_that("Reading example workbook", {
   sheet <- 1
   x <- read.xlsx(xlsxFile, sheet)
   y <- read.xlsx(wb, sheet)
+  expect_equal(dim(x), c(10, 7))
+  expect_equal(dim(y), c(10, 7))
   expect_equal(x, y)
   
   x <- read.xlsx(xlsxFile, sheet, detectDates = TRUE)
   y <- read.xlsx(wb, sheet, detectDates = TRUE)
+  expect_equal(dim(x), c(10, 7))
+  expect_equal(dim(y), c(10, 7))
   expect_equal(x, y)
   
   x <- read.xlsx(xlsxFile, sheet, startRow = 3, colNames = FALSE, detectDates = TRUE)
   y <- read.xlsx(wb, sheet, startRow = 3, colNames = FALSE, detectDates = TRUE)
+  expect_equal(dim(x), c(9, 5))
+  expect_equal(dim(y), c(9, 5))
   expect_equal(x, y)
   
   x <- read.xlsx(xlsxFile, sheet, rows = 2:4, colNames = TRUE, detectDates = TRUE)
   y <- read.xlsx(wb, sheet, rows = 2:4, colNames = TRUE, detectDates = TRUE)
+  expect_equal(dim(x), c(2, 6))
+  expect_equal(dim(y), c(2, 6))
   expect_equal(x, y)
   
   x <- read.xlsx(xlsxFile, sheet, rows = 2:4, colNames = FALSE, detectDates = TRUE)
   y <- read.xlsx(wb, sheet, rows = 2:4, colNames = FALSE, detectDates = TRUE)
+  expect_equal(dim(x), c(3, 6))
+  expect_equal(dim(y), c(3, 6))
   expect_equal(x, y)
   
   x <- read.xlsx(xlsxFile, sheet, rows = 2:4, colNames = FALSE, detectDates = FALSE)
   y <- read.xlsx(wb, sheet, rows = 2:4, colNames = FALSE, detectDates = FALSE)
+  expect_equal(dim(x), c(3, 6))
+  expect_equal(dim(y), c(3, 6))
   expect_equal(x, y)
   
   
   x <- read.xlsx(xlsxFile, sheet, colNames = FALSE, detectDates = FALSE, cols = 2:4)
   y <- read.xlsx(wb, sheet, colNames = FALSE, detectDates = FALSE, cols = 2:4)
+  expect_equal(dim(x), c(9, 2))
+  expect_equal(dim(y), c(9, 2))
   expect_equal(x, y)
   
   
@@ -48,27 +63,39 @@ test_that("Reading example workbook", {
   sheet <- 2
   x <- read.xlsx(xlsxFile, sheet)
   y <- read.xlsx(wb, sheet)
+  expect_equal(dim(x), c(33, 9))
+  expect_equal(dim(y), c(33, 9))
   expect_equal(x, y)
   
   x <- read.xlsx(xlsxFile, sheet, startRow = 3, colNames = FALSE, detectDates = TRUE)
   y <- read.xlsx(wb, sheet, startRow = 3, colNames = FALSE, detectDates = TRUE)
+  expect_equal(dim(x), c(32, 9))
+  expect_equal(dim(y), c(32, 9))
   expect_equal(x, y)
   
   x <- read.xlsx(xlsxFile, sheet, rows = 2:4, colNames = TRUE, detectDates = TRUE)
   y <- read.xlsx(wb, sheet, rows = 2:4, colNames = TRUE, detectDates = TRUE)
+  expect_equal(dim(x), c(2, 9))
+  expect_equal(dim(y), c(2, 9))
   expect_equal(x, y)
   
   x <- read.xlsx(xlsxFile, sheet, rows = 2:4, colNames = FALSE, detectDates = TRUE)
   y <- read.xlsx(wb, sheet, rows = 2:4, colNames = FALSE, detectDates = TRUE)
+  expect_equal(dim(x), c(3, 9))
+  expect_equal(dim(y), c(3, 9))
   expect_equal(x, y)
   
   x <- read.xlsx(xlsxFile, sheet, rows = 2:4, colNames = FALSE, detectDates = FALSE)
   y <- read.xlsx(wb, sheet, rows = 2:4, colNames = FALSE, detectDates = FALSE)
+  expect_equal(dim(x), c(3, 9))
+  expect_equal(dim(y), c(3, 9))
   expect_equal(x, y)
   
   
   x <- read.xlsx(xlsxFile, sheet, colNames = FALSE, detectDates = FALSE, cols = 2:4)
   y <- read.xlsx(wb, sheet, colNames = FALSE, detectDates = FALSE, cols = 2:4)
+  expect_equal(dim(x), c(21, 3))
+  expect_equal(dim(y), c(21, 3))
   expect_equal(x, y)
   
   
@@ -77,58 +104,87 @@ test_that("Reading example workbook", {
   sheet <- 3
   x <- read.xlsx(xlsxFile, sheet)
   y <- read.xlsx(wb, sheet)
+  expect_equal(dim(x), c(2083, 5))
+  expect_equal(dim(y), c(2083, 5))
   expect_equal(x, y)
   
   x <- read.xlsx(xlsxFile, sheet, startRow = 3, colNames = FALSE, detectDates = TRUE)
   y <- read.xlsx(wb, sheet, startRow = 3, colNames = FALSE, detectDates = TRUE)
+  expect_equal(dim(x), c(2084, 5))
+  expect_equal(dim(y), c(2084, 5))
   expect_equal(x, y)
   
   x <- suppressWarnings(read.xlsx(xlsxFile, sheet, rows = 2:4, colNames = TRUE, detectDates = TRUE))
   y <- suppressWarnings(read.xlsx(wb, sheet, rows = 2:4, colNames = TRUE, detectDates = TRUE))
+  expect_equal(dim(x), NULL)
+  expect_equal(dim(y), NULL)
   expect_equal(x, y)
   
   x <- suppressWarnings(read.xlsx(xlsxFile, sheet, rows = 2:4, colNames = FALSE, detectDates = TRUE))
   y <- suppressWarnings(read.xlsx(wb, sheet, rows = 2:4, colNames = FALSE, detectDates = TRUE))
+  expect_equal(dim(x), NULL)
+  expect_equal(dim(y), NULL)
+  expect_equal(x, NULL)
+  expect_equal(y, NULL)
   expect_equal(x, y)
   
   x <- suppressWarnings(read.xlsx(xlsxFile, sheet, rows = 2:4, colNames = FALSE, detectDates = FALSE))
   y <- suppressWarnings(read.xlsx(wb, sheet, rows = 2:4, colNames = FALSE, detectDates = FALSE))
+  expect_equal(dim(x), NULL)
+  expect_equal(dim(y), NULL)
+  expect_equal(x, NULL)
+  expect_equal(y, NULL)
   expect_equal(x, y)
   
   
   x <- read.xlsx(xlsxFile, sheet, colNames = FALSE, detectDates = FALSE, cols = 2:4)
   y <- read.xlsx(wb, sheet, colNames = FALSE, detectDates = FALSE, cols = 2:4)
+  expect_equal(dim(x), c(2084, 2))
+  expect_equal(dim(y), c(2084, 2))
   expect_equal(x, y)
   
-
+  
   
   ## sheet 5
   sheet <- 5
   x <- read.xlsx(xlsxFile, sheet)
   y <- read.xlsx(wb, sheet)
+  expect_equal(dim(x), c(271, 297))
+  expect_equal(dim(y), c(271, 297))
   expect_equal(x, y)
   
   x <- read.xlsx(xlsxFile, sheet, startRow = 3, colNames = FALSE, detectDates = TRUE)
   y <- read.xlsx(wb, sheet, startRow = 3, colNames = FALSE, detectDates = TRUE)
+  expect_equal(dim(x), c(270, 297))
+  expect_equal(dim(y), c(270, 297))
   expect_equal(x, y)
   
   x <- read.xlsx(xlsxFile, sheet, rows = 2:4, colNames = TRUE, detectDates = TRUE)
   y <- read.xlsx(wb, sheet, rows = 2:4, colNames = TRUE, detectDates = TRUE)
+  expect_equal(dim(x), c(2, 297))
+  expect_equal(dim(y), c(2, 297))
   expect_equal(x, y)
   
   x <- read.xlsx(xlsxFile, sheet, rows = 2:4, colNames = FALSE, detectDates = TRUE)
   y <- read.xlsx(wb, sheet, rows = 2:4, colNames = FALSE, detectDates = TRUE)
+  expect_equal(dim(x), c(3, 297))
+  expect_equal(dim(y), c(3, 297))
   expect_equal(x, y)
   
   x <- read.xlsx(xlsxFile, sheet, rows = 2:4, colNames = FALSE, detectDates = FALSE)
   y <- read.xlsx(wb, sheet, rows = 2:4, colNames = FALSE, detectDates = FALSE)
+  expect_equal(dim(x), c(3, 297))
+  expect_equal(dim(y), c(3, 297))
   expect_equal(x, y)
   
   
   x <- read.xlsx(xlsxFile, sheet, colNames = FALSE, detectDates = FALSE, cols = 2:4)
   y <- read.xlsx(wb, sheet, colNames = FALSE, detectDates = FALSE, cols = 2:4)
+  expect_equal(dim(x), c(272, 3))
+  expect_equal(dim(y), c(272, 3))
   expect_equal(x, y)
   
+  expect_equal(object = getwd(), curr_wd)
   
 })
 
@@ -139,6 +195,7 @@ test_that("Reading example workbook", {
 
 test_that("Load read - Skip Empty rows/cols", {
   
+  curr_wd <- getwd()
   xlsxFile <- system.file("readTest.xlsx", package = "openxlsx")
   wb <- loadWorkbook(xlsxFile)
   
@@ -244,11 +301,30 @@ test_that("Load read - Skip Empty rows/cols", {
   ## NA rows
   expect_true(all(is.na(x[2,])))
   
-  
+  expect_equal(object = getwd(), curr_wd)
   
 })
 
 
 
 
+context("Reading from workbook is identical to reading from file read_failure_test.xlsx")
+
+test_that("Reading example workbook read_failure_test.xlsx", {
+  
+  curr_wd <- getwd()
+  fl <- system.file("read_failure_test.xlsx", package = "openxlsx")
+  wb <- loadWorkbook(fl)
+  
+  x <- read.xlsx(fl, sheet = 1, skipEmptyCols = TRUE)
+  y <- read.xlsx(wb, sheet = 1, skipEmptyCols = TRUE)
+  expect_true(all.equal(x, y))
+  
+  x <- read.xlsx(fl, sheet = 1, skipEmptyCols = FALSE)
+  y <- read.xlsx(wb, sheet = 1, skipEmptyCols = FALSE)
+  expect_true(all.equal(x, y))
+
+  expect_equal(object = getwd(), curr_wd)
+
+})
 
